#
# spec file for package kio-gdrive
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without lang
Name:           kio-gdrive
Version:        1.3.0
Release:        bp153.2.2.1
Summary:        Google Drive KIO slave for KDE applications
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            https://community.kde.org/KIO_GDrive
Source:         https://download.kde.org/stable/%{name}/%{version}/src/%{name}-%{version}.tar.xz
BuildRequires:  extra-cmake-modules >= 5.48.0
BuildRequires:  intltool
BuildRequires:  cmake(KAccounts) >= 20.03.80
BuildRequires:  cmake(KF5DocTools) >= 5.48.0
BuildRequires:  cmake(KF5I18n) >= 5.48.0
BuildRequires:  cmake(KF5KIO) >= 5.48.0
BuildRequires:  cmake(KF5Notifications) >= 5.48.0
BuildRequires:  cmake(KPimGAPI) >= 5.11.41
BuildRequires:  cmake(Qt5Gui) >= 5.2.0
BuildRequires:  cmake(Qt5Network) >= 5.2.0
BuildRequires:  cmake(Qt5Widgets) >= 5.2.0
# Used by the .desktop file
Recommends:     dolphin
# libkgapi has no ABI stability
%requires_eq    libKPimGAPICore5

%lang_package

%description
Google Drive KIO slave for KDE applications.
KIO GDrive requires a KIO-enabled file manager at runtime,
otherwise there is no way to setup a Google Drive account.
This can be Dolphin or Gwenview or Konqueror.

%prep
%setup -q

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build
  %if %{with lang}
  %find_lang kio5_gdrive %{name}.lang
  %kf5_find_htmldocs
  %endif

%files
%license COPYING
%doc README.md README.packagers
%doc %lang(en) %{_kf5_htmldir}/en/kioslave5/gdrive/
%{_kf5_plugindir}/kaccounts/
%{_kf5_plugindir}/kf5/
%dir %{_datadir}/remoteview
%{_datadir}/remoteview/gdrive-network.desktop
%{_kf5_appstreamdir}/org.kde.kio_gdrive.metainfo.xml
%{_datadir}/accounts/
%{_kf5_notifydir}/gdrive.notifyrc

%if %{with lang}
%files lang -f %{name}.lang
%endif

%changelog
* Wed Apr 15 2020 wbauer@tmo.at
- Update to 1.3.0
  * Support for the Shared Drives feature of Google Drive
  * New "Copy Google URL to clipboard" action in the Dolphin
    context-menu
  * Support for the new kaccounts-integration 20.04 release
  * Improved appstream metadata
  * Fixed opening docx files as archives in remote folders
    (kde#401151)
* Sat Aug 24 2019 wbauer@tmo.at
- Update to 1.2.7
  * Fix the build against libkgapi >= 19.08 while keeping
    compatibility with older libkgapi
- Drop patches that are no longer necessary:
  * Adapt-to-LibKGAPI-setFields-changes.patch
  * Remove-useless-FileFetchJob-field-specifications.patch
* Tue Aug 20 2019 wbauer@tmo.at
- Require same libkgapi version as it was built against, there is
  no ABI stability guarantee and there were incompatible changes
  again in 19.08
* Sat Jul 27 2019 wbauer@tmo.at
- Add upstream patches to fix build with libkgapi 19.08:
  * Adapt-to-LibKGAPI-setFields-changes.patch
  * Remove-useless-FileFetchJob-field-specifications.patch
- Add missing BuildRequires explicitly that were pulled in by other
  packages
* Tue May 21 2019 wbauer@tmo.at
- Update to 1.2.6
  * Updated translations
* Sat Apr 27 2019 wbauer@tmo.at
- Point URL to the page on the KDE Community Wiki
- Use https for URLs
- Switch Qt5/KF5 BuildRequires to cmake() syntax
* Sun Oct 21 2018 wbauer@tmo.at
- Update to 1.2.5
  * Fixed downloading of large files (kde#375765)
  * Fixed component tag in the appstream file
  * Updated translations
- Drop 0001-Send-file-contents-in-chunks.patch, merged upstream
* Sun Sep 30 2018 fabian@ritter-vogt.de
- Add patch to fix transfer of files >= 16MiB (kde#375765):
  * 0001-Send-file-contents-in-chunks.patch
- Use %%license
* Mon Jul  2 2018 wbauer@tmo.at
- Update to 1.2.4
  * Fixed opening files with special characters in their name (kde#395590)
  * Fixed homepage URL in the appstream file
  * Updated translations
* Sun Apr 22 2018 wbauer@tmo.at
- Update to 1.2.3
  * Added missing copy of GPL3 license
  * Updated translations
* Sun Apr  1 2018 wbauer@tmo.at
- Update to 1.2.2
  * Fixed mimetype used to open .ods files (kde#388598)
  * Fixed copy of files within the same gdrive account (kde#376735)
  * Updated translations
- Drop 0001-MIME-type-correction-for-ods-files.patch, merged
  upstream
* Tue Feb 13 2018 alarrosa@suse.com
- Add patch to fix opening ods files using kio-gdrive, since the file
  has an invalid MIME type x-vnd.oasis.opendocument.spreadsheet (kde#388598)
  * 0001-MIME-type-correction-for-ods-files.patch
* Sun Oct  1 2017 wbauer@tmo.at
- Update to 1.2.1
  * Fixed build against latest libkgapi.
  * Updated translations.
* Wed Jul  5 2017 jengelh@inai.de
- Grammar fixes to description.
* Fri Jun  2 2017 wbauer@tmo.at
- Update to 1.2.0.1
  * build fixes
* Fri May 26 2017 wbauer@tmo.at
- Update to 1.2.0
  * Integration with KAccounts
  * Google Drive free space is now reported
- Adjust build requirements to enable the new KAccounts integration
* Fri May 19 2017 wbauer@tmo.at
- Update to 1.1.2
  * Updated translations, including translated documentation which
    was previously missing.
* Tue Feb 14 2017 wbauer@tmo.at
- Update to 1.1.1
  * Fixed wrong write permissions in the top-level accounts folder.
* Thu Jan 26 2017 fabian@ritter-vogt.de
- Update to 1.1.0
  * Feature release
  * No changelog, see https://eang.it/kio-gdrive-1-1-released/
* Wed Jan 11 2017 wbauer@tmo.at
- Update to 1.0.5
  * Some translation updates
* Sat Nov 12 2016 wbauer@tmo.at
- Update to 1.0.4
  * Fixed an issue that would make some files hidden (kde#371954)
  * Added TryExec key in the .desktop file.
* Mon Oct 17 2016 wbauer@tmo.at
- Update to 1.0.3
  * Stop trashing all account files on account removal
* Fri Oct  7 2016 wbauer@tmo.at
- Update to 1.0.2
  * Fix copy-pasting from gdrive:// URLs to local disk (kde#369619)
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 1.0.1
  * Fix broken QUrl construction (kde#367988, kde#369581)
* Fri Sep 30 2016 fabian@ritter-vogt.de
- Update to stable version 1.0.0
